@@ -557,6 +557,7 @@ class TestOpenApi3HttpDomain(object):
                 - type: number
                 - type: boolean
                 - $ref: '#/components/schemas/Test4'
+                - $ref: '#/components/schemas/Test5'
             Test2:
               type: object
               properties:
@@ -578,6 +579,9 @@ class TestOpenApi3HttpDomain(object):
                 field4:
                   type: string
               additionalProperties: false
+            Test5:
+              type: string
+              enum: [A, B]
         """))
         text = '\n'.join(renderer.render_restructuredtext_markup(spec))
         assert text == textwrap.dedent("""
@@ -595,8 +599,9 @@ class TestOpenApi3HttpDomain(object):
               - Type
               - Description
               - Required
-            * - ``...``
-              - One of string, integer, number, boolean, :ref:`Test4 </components/schemas/Test4>`
+            * - ``*``
+              - One of string, integer, number, boolean, """ +
+                                       """:ref:`Test4 </components/schemas/Test4>`, enumerate (``A``, ``B``)
               - Additional properties
               -
 
@@ -659,6 +664,7 @@ class TestOpenApi3HttpDomain(object):
               - string
               -
               -
+
         """)
 
     def test_allof(self):
@@ -715,7 +721,7 @@ class TestOpenApi3HttpDomain(object):
               - Type
               - Description
               - Required
-            * - ``...``
+            * - ``*``
               - All of string, integer, number, boolean, :ref:`Test4 </components/schemas/Test4>`
               - Additional properties
               -
@@ -835,7 +841,7 @@ class TestOpenApi3HttpDomain(object):
               - Type
               - Description
               - Required
-            * - ``...``
+            * - ``*``
               - Any of string, integer, number, boolean, :ref:`Test4 </components/schemas/Test4>`
               - Additional properties
               -
@@ -901,6 +907,53 @@ class TestOpenApi3HttpDomain(object):
               -
         """)
 
+    def test_others_additional(self):
+        renderer = renderers.ModelRenderer(None, {})
+        spec = yaml.safe_load(textwrap.dedent("""
+        ---
+        openapi: 3.0.0
+        paths: {}
+        components:
+          schemas:
+            Test1:
+              type: object
+              required:
+                - field1
+              properties:
+                field1:
+                  type: string
+                  example: F1
+                others:
+                  type: object
+                  additionalProperties: true
+              additionalProperties: false
+        """))
+        text = '\n'.join(renderer.render_restructuredtext_markup(spec))
+        assert text == textwrap.dedent("""
+        .. _/components/schemas/Test1:
+
+        Test1
+        '''''
+
+        .. list-table:: Test1
+            :header-rows: 1
+            :widths: 25 25 45 15
+            :class: longtable
+
+            * - Attribute
+              - Type
+              - Description
+              - Required
+            * - ``field1``
+              - string
+              -
+              - Yes
+            * - ``others.*``
+              -
+              - Additional properties
+              -
+        """)
+
     def test_filtering(self):
         spec = yaml.safe_load(textwrap.dedent("""
         ---
